/// <reference types="react" />
import React$1 from 'react';

declare const themes: {
    default: DefaultTheme;
} & Record<string, Theme>;
declare const themeableElements: readonly ["container", "property", "bracket", "itemCount", "string", "number", "boolean", "null", "input", "inputHighlight", "error", "iconCollection", "iconEdit", "iconDelete", "iconAdd", "iconCopy", "iconOk", "iconCancel"];
type ThemeableElement = (typeof themeableElements)[number];
type ThemeValue = string | React.CSSProperties | Array<string | React.CSSProperties>;
type ThemeStyles = Record<ThemeableElement, ThemeValue>;
type Fragments = Record<string, React.CSSProperties | string>;
interface Theme {
    displayName?: string;
    fragments?: Fragments;
    styles: Partial<ThemeStyles>;
}
interface DefaultTheme extends Theme {
    displayName: 'Default';
    styles: ThemeStyles;
}
type CompiledStyles = Record<ThemeableElement, React.CSSProperties>;
type ThemeName = keyof typeof themes;
type ThemeInput = ThemeName | Theme | Partial<ThemeStyles> | [ThemeName, Theme | Partial<ThemeStyles>];

declare const localisedStrings: {
    ITEM_SINGLE: string;
    ITEMS_MULTIPLE: string;
    KEY_NEW: string;
    ERROR_KEY_EXISTS: string;
    ERROR_INVALID_JSON: string;
    ERROR_UPDATE: string;
    ERROR_DELETE: string;
    ERROR_ADD: string;
    DEFAULT_STRING: string;
    DEFAULT_NEW_KEY: string;
};
type LocalisedStrings = typeof localisedStrings;
type TranslateFunction = (key: keyof LocalisedStrings, customData: NodeData, count?: number) => string;

interface JsonEditorProps {
    data: object;
    rootName?: string;
    onUpdate?: UpdateFunction;
    onEdit?: UpdateFunction;
    onDelete?: UpdateFunction;
    onAdd?: UpdateFunction;
    enableClipboard?: boolean | CopyFunction;
    theme?: ThemeInput;
    icons?: IconReplacements;
    className?: string;
    indent?: number;
    collapse?: boolean | number | FilterFunction;
    showCollectionCount?: boolean | 'when-closed';
    restrictEdit?: boolean | FilterFunction;
    restrictDelete?: boolean | FilterFunction;
    restrictAdd?: boolean | FilterFunction;
    restrictTypeSelection?: boolean | DataType[] | TypeFilterFunction;
    keySort?: boolean | CompareFunction;
    showArrayIndices?: boolean;
    defaultValue?: unknown;
    minWidth?: string | number;
    maxWidth?: string | number;
    stringTruncate?: number;
    translations?: Partial<LocalisedStrings>;
    customNodeDefinitions?: CustomNodeDefinition[];
    customText?: CustomTextDefinitions;
}
declare const DataTypes: readonly ["string", "number", "boolean", "null", "object", "array"];
type DataType = (typeof DataTypes)[number] | 'invalid';
type CollectionKey = string | number;
type CollectionData = object | unknown[];
type ErrorString = string;
interface IconReplacements {
    add?: JSX.Element;
    edit?: JSX.Element;
    delete?: JSX.Element;
    copy?: JSX.Element;
    ok?: JSX.Element;
    cancel?: JSX.Element;
    chevron?: JSX.Element;
}
type UpdateFunction = (props: {
    newData: object;
    currentData: object;
    newValue: unknown;
    currentValue: unknown;
    name: CollectionKey;
    path: CollectionKey[];
}) => void | ErrorString | false;
type FilterFunction = (input: NodeData) => boolean;
type TypeFilterFunction = (input: NodeData) => boolean | DataType[];
type CustomTextFunction = (input: NodeData) => string | null;
type CopyType = 'path' | 'value';
type CopyFunction = (input: {
    key: CollectionKey;
    path: CollectionKey[];
    value: unknown;
    stringValue: string;
    type: CopyType;
}) => void;
type CompareFunction = (a: string, b: string) => number;
type OnChangeFunction = (value: unknown, path: (string | number)[]) => Promise<string | void>;
interface NodeData {
    key: CollectionKey;
    path: CollectionKey[];
    level: number;
    value: unknown;
    size: number | null;
}
interface BaseNodeProps {
    data: unknown;
    parentData: CollectionData | null;
    nodeData: NodeData;
    onEdit: OnChangeFunction;
    onDelete: OnChangeFunction;
    enableClipboard: boolean | CopyFunction;
    restrictEditFilter: FilterFunction;
    restrictDeleteFilter: FilterFunction;
    restrictAddFilter: FilterFunction;
    restrictTypeSelection: boolean | DataType[] | TypeFilterFunction;
    stringTruncate: number;
    indent: number;
    translate: TranslateFunction;
    customNodeDefinitions: CustomNodeDefinition[];
}
interface CollectionNodeProps extends BaseNodeProps {
    data: CollectionData;
    collapseFilter: FilterFunction;
    onAdd: OnChangeFunction;
    keySort: boolean | CompareFunction;
    showArrayIndices: boolean;
    showCollectionCount: boolean | 'when-closed';
    defaultValue: unknown;
}
type ValueData = string | number | boolean;
interface ValueNodeProps extends BaseNodeProps {
    data: ValueData;
    showLabel: boolean;
}
interface CustomNodeProps<T = Record<string, unknown>> extends BaseNodeProps {
    value: ValueData | CollectionData;
    customNodeProps?: T;
    parentData: CollectionData | null;
    setValue: React$1.Dispatch<React$1.SetStateAction<ValueData>>;
    handleEdit: () => void;
    handleCancel: () => void;
    handleKeyPress: (e: React$1.KeyboardEvent) => void;
    isEditing: boolean;
    setIsEditing: React$1.Dispatch<React$1.SetStateAction<boolean>>;
    styles: CompiledStyles;
}
interface CustomNodeDefinition<T = Record<string, unknown>> {
    condition: FilterFunction;
    element: React$1.FC<CustomNodeProps<T>>;
    name?: string;
    customNodeProps?: Record<string, unknown>;
    hideKey?: boolean;
    defaultValue?: unknown;
    showInTypesSelector?: boolean;
    showOnEdit?: boolean;
    showOnView?: boolean;
    showEditTools?: boolean;
}
type CustomTextDefinitions = Partial<{
    [key in keyof LocalisedStrings]: CustomTextFunction;
}>;

declare const JsonEditor: React$1.FC<JsonEditorProps>;

declare const LinkCustomComponent: React$1.FC<CustomNodeProps<{
    stringTruncate?: number;
}>>;
declare const LinkCustomNodeDefinition: CustomNodeDefinition;

export { CollectionNodeProps, CompareFunction, CopyFunction, CustomNodeDefinition, CustomNodeProps, CustomTextDefinitions, FilterFunction, IconReplacements, JsonEditor, JsonEditorProps, LinkCustomComponent, LinkCustomNodeDefinition, LocalisedStrings, Theme, ThemeInput, ThemeName, TranslateFunction, UpdateFunction, ValueNodeProps, themes };
